// Translated by:  Bohdan Horst <nexus@hoth.amu.edu.pl>
// Wszelkie uwagi i poprawki mile widziane :)
//
// Fixes and updates: Wojtek Kaniewski <wojtekka@bydg.pdi.net>
// Last sync on 2003-07-30 with help_mp-en.h 1.95

// ========================= MPlayer help ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Uycie:   mplayer [opcje] [url|cieka/]nazwa\n"
"\n"
"Podstawowe opcje: (pena lista w manualu)\n"
" -vo <drv[:dev]> wybr sterownika[:urzdzenia] video (lista po '-vo help')\n"
" -ao <drv[:dev]> wybr sterownika[:urzdzenia] audio (lista po '-ao help')\n"
#ifdef HAVE_VCD
" -vcd <trackno>  odtwarzanie bezporednio cieki VCD (video cd)\n"
#endif
#ifdef HAVE_LIBCSS
" -dvdauth <dev>  urzdzenie DVD do autoryzacji (dla zaszyfrowanych dyskw)\n"
#endif
#ifdef USE_DVDREAD
" -dvd <titleno>  odtwarzanie bezporednio tytuu DVD\n"
" -alang/-slang   jzyk dla dwiku/napisw (poprzez 2-znakowy kod kraju)\n"
#endif
" -ss <timepos>   skok do podanej pozycji (sekundy albo hh:mm:ss)\n"
" -nosound        odtwarzanie bez dwiku\n"
" -fs -vm -zoom   opcje penoekranowe (peen ekran,zmiana trybu,skalowanie)\n"
" -x <x> -y <y>   wybr rozdzielczoci ekranu (dla -vm lub -zoom)\n"
" -sub <plik>     wybr pliku z napisami (zobacz take -subfps, -subdelay)\n"
" -playlist <plik>wybr pliku z playlist\n"
" -vid x -aid y   wybr odtwarzanego strumienia video (x) i audio (y)\n"
" -fps x -srate y wybr prdkoci odtwarzania video (x fps) i audio (y Hz)\n"
" -pp <opcje>     wybr postprocesingu (zobacz manual)\n"
" -framedrop      gubienie klatek (dla wolnych maszyn)\n"
"\n"
"Podstawowe klawisze: (pena lista w manualu, sprawd take input.conf)\n"
" Right,Up,PgUp   skok naprzd o 10 sekund, 1 minut, 10 minut\n"
" Left,Down,PgDn  skok do tyu o 10 sekund, 1 minut, 10 minut\n"
" < lub >         przeskok o jedn pozycj w playlicie\n"
" p lub SPACE     zatrzymanie filmu (kontynuacja - dowolny klawisz)\n"
" q lub ESC       zatrzymanie odtwarzania i wyjcie z programu\n"
" + lub -         regulacja opnienia dwiku o +/- 0,1 sekundy\n"
" o               przeczanie trybw OSD: pusty / belka / belka i zegar\n"
" * lub /         zwikszenie lub zmniejszenie natenia dwiku\n"
" z lub x         regulacja opnienia napisw o +/- 0,1 sekundy\n"
" r lub t         regulacja pooenia napisw (zobacz take -vop expand)\n"
"\n"
" **** DOKADNY SPIS WSZYSTKICH DOSTPNYCH OPCJI ZNAJDUJE SI W MANUALU! ****\n"
"\n";
#endif

// ========================= MPlayer messages ===========================

// mplayer.c: 

#define MSGTR_Exiting "\nWychodz... (%s)\n"
#define MSGTR_Exit_quit "Wyjcie"
#define MSGTR_Exit_eof "Koniec pliku"
#define MSGTR_Exit_error "Bd krytyczny"
#define MSGTR_IntBySignal "\nMPlayer przerwany sygnaem %d w module: %s \n"
#define MSGTR_NoHomeDir "Nie mog znale katalogu domowego\n"
#define MSGTR_GetpathProblem "problem z get_path(\"config\")\n"
#define MSGTR_CreatingCfgFile "Tworz plik z konfiguracj: %s\n"
#define MSGTR_InvalidVOdriver "Nieprawidowa nazwa sterownika video: %s\nUyj '-vo help' aby dosta list dostpnych sterownikw video.\n"
#define MSGTR_InvalidAOdriver "Nieprawidowa nazwa sterownika audio: %s\nUyj '-ao help' aby dosta list dostpnych sterownikw audio.\n"
#define MSGTR_CopyCodecsConf "(skopiuj/zlinkuj etc/codecs.conf do ~/.mplayer/codecs.conf)\n"
#define MSGTR_BuiltinCodecsConf "Uywam domylnego (wkompilowanego) codecs.conf\n"
#define MSGTR_CantLoadFont "Nie mog zaadowa czcionki: %s\n"
#define MSGTR_CantLoadSub "Nie mog zaadowa napisw: %s\n"
#define MSGTR_ErrorDVDkey "Bd w przetwarzaniu DVD KEY.\n"
#define MSGTR_CmdlineDVDkey "dany klucz DVD uywany jest do dekodowania.\n"
#define MSGTR_DVDauthOk "Sekwencja autoryzacji DVD wyglda OK.\n"
#define MSGTR_DumpSelectedStreamMissing "dump: FATAL: nie ma wybranego strumienia!\n"
#define MSGTR_CantOpenDumpfile "Nie mog otworzy pliku dump.\n"
#define MSGTR_CoreDumped "Core dumped ;)\n"
#define MSGTR_FPSnotspecified "FPS nie podane (lub bdne) w nagwku. Uyj opcji -fps.\n"
#define MSGTR_TryForceAudioFmtStr "Wymuszam zastosowanie kodeka audio z rodziny %s ...\n"
#define MSGTR_CantFindAfmtFallback "Nie mog znale kodeka audio dla wymuszonej rodziny, wracam do standardowych.\n"
#define MSGTR_CantFindAudioCodec "Nie mog znale kodeka dla formatu audio 0x%X.\n"
#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** Sprbuj uaktualni %s etc/codecs.conf\n*** Jeli to nie pomaga, przeczytaj DOCS/codecs.html!\n"
#define MSGTR_CouldntInitAudioCodec "Nie moge zainicjowa sterownika audio -> brak dwiku.\n"
#define MSGTR_TryForceVideoFmtStr "Wymuszam zastosowanie kodeka video z rodziny %s ...\n"
#define MSGTR_CantFindVideoCodec "Nie mog znale kodeka dla wybranego -vo i formatu video 0x%X.\n"
#define MSGTR_VOincompCodec "Przykro mi, wybrany sterownik video_out jest niekompatybilny z tym kodekiem.\n"
#define MSGTR_CannotInitVO "BD: Nie mog zainicjowa sterownika video.\n"
#define MSGTR_CannotInitAO "Nie mog otworzy/zainicjowa urzdzenia audio -> brak dwiku.\n"
#define MSGTR_StartPlaying "Pocztek odtwarzania...\n"

#define MSGTR_SystemTooSlow "\n\n"\
"         ************************************\n"\
"         *** Twj system jest zbyt wolny! ***\n"\
"         ************************************\n"\
"Moliwe przyczyny, problemy, rozwizania: \n"\
"- Najczstsza przyczyna: uszkodzony/obarczony bdami sterownik _audio_.\n"\
"  Rozwizanie: sprbuj -ao sdl lub uyj ALSA 0.5 lub emulacj OSS w ALSA 0.9\n"\
"  Przeczytaj DOCS/sound.html!\n"\
"  Moesz take eksperymentowa z -autosync 30 (lub innymi wartociami).\n"\
"- Wolny sterownik video. Sprbuj z inny sterownikiem -vo (lista: -vo help)\n"\
"  lub odtwarzaj z opcj -framedrop!\n"\
"- Wolny procesor. Nie odtwarzaj duych DVD/DivX na wolnych procesorach!\n"\
"  Sprbuj z opcj -hardframedrop.\n"\
"- Uszkodzony plik. Sprbuj rnych kombinacji: -nobps -ni -mc 0 -forceidx.\n"\
"- Odtwarzajc z wolnego rda (zamontowane partycje NFS/SMB, DVD, VCD itp)\n"\
"  sprbuj z opcj -cache 8192\n"\
"- Uywasz -cache do odtwarzania plikow non-interleaved? Sprbuj z -nocache\n"\
"Przeczytaj DOCS/video.html i DOCS/sound.html -- znajdziesz tam wskazwki\n"\
"jak przyspieszy dziaanie. Jeli nic z powyszego nie pomaga, przeczytaj\n"\
"DOCS/bugreports.html.\n\n"

#define MSGTR_NoGui "MPlayer zosta skompilowany BEZ obsugi GUI.\n"
#define MSGTR_GuiNeedsX "GUI MPlayera wymaga X11.\n"
#define MSGTR_Playing "Odtwarzam %s\n"
#define MSGTR_NoSound "Audio: brak dwiku\n"
#define MSGTR_FPSforced "FPS wymuszone na %5.3f  (ftime: %5.3f)\n"
#define MSGTR_CompiledWithRuntimeDetection "Skompilowane z wykrywaniem procesora - UWAGA - to nie jest optymalne!\nAby uzyska lepsz wydajno, przekompiluj MPlayera z opcj\n--disable-runtime-cpudetection\n"
#define MSGTR_CompiledWithCPUExtensions "Skompilowane dla x86 CPU z rozszerzeniami:"
#define MSGTR_AvailableVideoOutputPlugins "Dostpne pluginy video:\n"
#define MSGTR_AvailableVideoOutputDrivers "Dostpne sterowniki video:\n"
#define MSGTR_AvailableAudioOutputDrivers "Dostpne sterowniki audio:\n"
#define MSGTR_AvailableAudioCodecs "Dostpne kodeki audio:\n"
#define MSGTR_AvailableVideoCodecs "Dostpne kodeki video:\n"
#define MSGTR_AvailableAudioFm "\nDostpne (wkompilowane) rodziny kodekw audio/sterowniki:\n"
#define MSGTR_AvailableVideoFm "\nDostpne (wkompilowane) rodziny kodekw video/sterowniki:\n"
#define MSGTR_AvailableFsType "Dostpne tryby penoekranowe:\n"
#define MSGTR_UsingRTCTiming "Uywam Linux's hardware RTC timing (%ldHz)\n"
#define MSGTR_CannotReadVideoProperties "Video: nie mog odczyta waciwoci\n"
#define MSGTR_NoStreamFound "Nie znaleziono strumienia.\n"
#define MSGTR_InitializingAudioCodec "Inicjalizuj kodek audio...\n"
#define MSGTR_ErrorInitializingVODevice "Bd otwierania/inicjalizacji wybranego video_out (-vo) urzdzenia!\n"
#define MSGTR_ForcedVideoCodec "Wymuszony kodek video: %s\n"
#define MSGTR_ForcedAudioCodec "Wymuszony kodek audio: %s\n"
#define MSGTR_AODescription_AOAuthor "AO: Opis: %s\nAO: Autor: %s\n"
#define MSGTR_AOComment "AO: Komentarz: %s\n"
#define MSGTR_Video_NoVideo "Video: brak video\n"
#define MSGTR_NotInitializeVOPorVO "\nFATAL: Nie mog zainicjowa filtrw video (-vop) lub wyjcia video (-vo).\n"
#define MSGTR_Paused "\n  =====  PAUZA  =====\r"
#define MSGTR_PlaylistLoadUnable "\nNie mona zaadowa playlisty %s.\n"
#define MSGTR_Exit_SIGILL_RTCpuSel \
"- MPlayer wykona nieprawidow operacj.\n"\
"  By moe to bd w nowym kodzie wykrywania procesora...\n"\
"  Przeczytaj DOCS/bugreports.html.\n"
#define MSGTR_Exit_SIGILL \
"- MPlayer wykona nieprawidow operacj.\n"\
"  Zwykle zdarza si to, gdy uruchamiasz go na innym procesorze ni ten,\n"\
"  dla ktrego zosta skompilowany/zoptymalizowany.\n  Sprawd to!\n"
#define MSGTR_Exit_SIGSEGV_SIGFPE \
"- MPlayer wykona nieprawidow operacj zwizan z pamici/koprocesorem.\n"\
"  Przekompiluj MPlayera z --enable-debug i wykonad backtrace 'gdb' i\n"\
"  deasemblacj. Szczegy w pliku DOCS/bugreports.html#crash\n"
#define MSGTR_Exit_SIGCRASH \
"- MPlayer wykona nieprawidow operacj. To nie powinno si zdarzy.\n"\
"  By moe to bd w kodzie MPlayera _lub_ w Twoich sterownikach _lub_\n"\
"  w uywanej przez Ciebie wersji gcc. Jeli mylisz, e to wina MPlayera,\n"\
"  przeczytaj prosz DOCS/bugreports.html i postpuj zgodnie z instrukacjami.\n"\
"  Nie moemy pomc i nie pomoemy jeli nie dostarczysz tych informacji przy\n"\
"  zgaszaniu bdu.\n"
	

// mencoder.c:

#define MSGTR_UsingPass3ControllFile "Uywam pliku kontrolnego pass3: %s\n"
#define MSGTR_MissingFilename "\nBrak nazwy pliku.\n\n"
#define MSGTR_CannotOpenFile_Device "Nie mona otworzy pliku/urzdzenia.\n"
#define MSGTR_ErrorDVDAuth "Bad w autoryzacji DVD.\n"
#define MSGTR_CannotOpenDemuxer "Nie mona otworzy demuxera\n"
#define MSGTR_NoAudioEncoderSelected "\nNie wybrano enkodera audio (-oac). Wybierz jeden lub uyj -nosound. Uyj -oac help!\n"
#define MSGTR_NoVideoEncoderSelected "\nNie wybrano enkodera video (-ovc). Wybierz jeden, uyj -ovc help!\n"
#define MSGTR_InitializingAudioCodec "Inicjalizuje kodek audio...\n"
#define MSGTR_CannotOpenOutputFile "Nie mog otworzy pliku wynikowego: '%s'.\n"
#define MSGTR_EncoderOpenFailed "Nie mog otworzy encodera.\n"
#define MSGTR_ForcingOutputFourcc "Wymuszam fourcc wynikowe na %x [%.4s]\n"
#define MSGTR_WritingAVIHeader "Zapisuje nagwek AVI...\n"
#define MSGTR_DuplicateFrames "\npowtrzone %d ramek!\n"
#define MSGTR_SkipFrame "\nOpuszczam ramk!\n"
#define MSGTR_ErrorWritingFile "%s: Bd zapisu pliku.\n"
#define MSGTR_WritingAVIIndex "\nZapisuj indeks AVI...\n"
#define MSGTR_FixupAVIHeader "Naprawiam nagwek AVI...\n"
#define MSGTR_RecommendedVideoBitrate "Zalecane video bitrate dla %s CD: %d\n"
#define MSGTR_VideoStreamResult "\nStrumie video: %8.3f kbit/s (%d bps) rozmiar: %d bajtw %5.3f sekund %d ramek\n"
#define MSGTR_AudioStreamResult "\nStrumie audio: %8.3f kbit/s (%d bps) rozmiar: %d bajtw %5.3f sekund\n"

// cfg-mencoder.h:

#define MSGTR_MEncoderMP3LameHelp "\n\n"\
" vbr=<0-4>     metoda zmiennego bitrate\n"\
"                0: cbr\n"\
"                1: mt\n"\
"                2: rh(domylna)\n"\
"                3: abr\n"\
"                4: mtrh\n"\
"\n"\
" abr           redni bitrate\n"\
"\n"\
" cbr           stay bitrate\n"\
"               Wymusza rwnie kodowanie CBR w nastpujcych po tej opcji\n"\
"               ustawieniach ABR\n"\
"\n"\
" br=<0-1024>   podaje bitrate w kilobitach (tylko CBR i ABR)\n"\
"\n"\
" q=<0-9>       jako (0-najwysza, 9-najnisza) (tylko VBR)\n"\
"\n"\
" aq=<0-9>      jako algorytmu (0-najlepsza/najwolniejsza,\n"\
"               9-najgorsza/najszybsza)\n"\
"\n"\
" ratio=<1-100> wspczynnik kompresji\n"\
"\n"\
" vol=<0-10>    wzmocnienie sygnau audio\n"\
"\n"\
" mode=<0-3>    (domylnie: auto)\n"\
"                0: stereo\n"\
"                1: joint-stereo\n"\
"                2: dualchannel\n"\
"                3: mono\n"\
"\n"\
" padding=<0-2>\n"\
"                0: no\n"\
"                1: all\n"\
"                2: adjust\n"\
"\n"\
" fast          wcza szybsze kodowanie w nastpujcych po tej opcji\n"\
"               ustawieniach VBR, nieznacznie nisza jako i wyszy bitrate.\n"\
"\n"\
" preset=<value>  wcza najwysze moliwe ustawienia jakoci.\n"\
"                 medium: kodowanie VBR, dobra jako\n"\
"                 (bitrate w zakresie 150-180 kbps)\n"\
"                 standard: kodowanie VBR, wysoka jako\n"\
"                 (bitrate w zakresie 170-210 kbps)\n"\
"                 extreme: kodowanie VBR, bardzo wysoka jako\n"\
"                 (bitrate w zakresie 200-240 kbps)\n"\
"                 insane: kodowanie CBR, najwysza moliwa jako\n"\
"                 (bitrate 320 kbps)\n"\
"                 <8-320>: kodowanie ABR przy podanym rednim bitrate.\n\n"
	
// open.c, stream.c:
#define MSGTR_CdDevNotfound "Urzdzenie CD-ROM '%s' nie znalezione.\n"
#define MSGTR_ErrTrackSelect "Bd wyboru cieki VCD."
#define MSGTR_ReadSTDIN "Odczytuj ze stdin...\n"
#define MSGTR_UnableOpenURL "Nie mog otworzy URL: %s\n"
#define MSGTR_ConnToServer "Poczony z serwerem: %s\n"
#define MSGTR_FileNotFound "Plik nieznaleziony: '%s'\n"

#define MSGTR_SMBInitError "Nie mog zainicjowa biblioteki libsmbclient: %d\n"
#define MSGTR_SMBFileNotFound "Nie mog otworzy z sieci: '%s'\n"
#define MSGTR_SMBNotCompiled "MPlayer nie zosta skompilowany z obsug SMB\n"

#define MSGTR_CantOpenDVD "Nie mog otworzy urzdzenia DVD: %s\n"
#define MSGTR_DVDwait "Odczytuj struktur dysku, prosz czeka...\n"
#define MSGTR_DVDnumTitles "Na tym DVD znajduje si %d tytuw.\n"
#define MSGTR_DVDinvalidTitle "Nieprawidowy numer tytuu DVD: %d\n"
#define MSGTR_DVDnumChapters "W tym tytule DVD znajduje si %d rozdziaw.\n"
#define MSGTR_DVDinvalidChapter "Nieprawidowy numer rozdziau DVD: %d\n"
#define MSGTR_DVDnumAngles "W tym tytule DVD znajduje si %d ustawie kamery.\n"
#define MSGTR_DVDinvalidAngle "Nieprawidowy numer ustawienia kamery DVD: %d\n"
#define MSGTR_DVDnoIFO "Nie mog otworzy pliku IFO dla tytuu DVD %d.\n"
#define MSGTR_DVDnoVOBs "Nie mog otworzy tytuu VOBS (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD otwarte poprawnie!\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "Uwaga! Nagwek strumienia audio %d zdefiniowany ponownie.\n"
#define MSGTR_VideoStreamRedefined "Uwaga! Nagwek strumienia video %d zdefiniowany ponownie.\n"
#define MSGTR_TooManyAudioInBuffer "\nZbyt wiele (%d w %d bajtach) pakietw audio w buforze.\n"
#define MSGTR_TooManyVideoInBuffer "\nZbyt wiele (%d w %d bajtach) pakietw video w buforze.\n"
#define MSGTR_MaybeNI "Moe odtwarzasz strumie/plik non-interleaved lub kodek nie zadziaa?\n"\
		      "Dla plikw .AVI sprbuj wymusi tryb non-interleaved poprzez opcje -ni\n"
#define MSGTR_SwitchToNi "\nWykryto non-interleaved .AVI - przeczam na tryb -ni...\n"
#define MSGTR_Detected_XXX_FileFormat "Wykryto format %s.\n"
#define MSGTR_DetectedAudiofile "Wykryto plik audio.\n"
#define MSGTR_NotSystemStream "Nie jest to MPEG System Stream... (moe Transport Stream?)\n"
#define MSGTR_InvalidMPEGES "Bdny strumie MPEG-ES??? Skontaktuj si z autorem, moe to bd :(\n"
#define MSGTR_FormatNotRecognized "=========== Przykro mi, nierozpoznany/nieobsugiwany format pliku ===========\n"\
				  "=== Jeli to strumie AVI, ASF lub MPEG, prosz skontaktuj si z autorem! ===\n"
#define MSGTR_MissingVideoStream "Nie znaleziono strumienia video.\n"
#define MSGTR_MissingAudioStream "Nie znaleziono strumienia audio -> brak dwiku.\n"
#define MSGTR_MissingVideoStreamBug "Brakujcy strumie video?! Skontaktuj si z autorem, moe to bd :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: Plik nie zawiera wybranego strumienia audio lub video\n"

#define MSGTR_NI_Forced "Wymuszony"
#define MSGTR_NI_Detected "Wykryty"
#define MSGTR_NI_Message "%s format pliku NON-INTERLEAVED AVI.\n"

#define MSGTR_UsingNINI "Uywa uszkodzonego formatu pliku NON-INTERLEAVED AVI.\n"
#define MSGTR_CouldntDetFNo "Nie mog okreli liczby klatek (dla przeszukiwania)\n"
#define MSGTR_CantSeekRawAVI "Nie mog przeszukiwa nieindeksowanych strumieni .AVI! (sprawd opcj -idx!)\n"
#define MSGTR_CantSeekFile "Nie mog przeszukiwa tego pliku.\n"

#define MSGTR_EncryptedVOB "Zaszyfrowany plik VOB (nie wkompilowano obsugi libcss)! Przeczytaj DOCS/cd-dvd.html\n"
#define MSGTR_EncryptedVOBauth "Zaszyfrowany strumie, nie zadae autoryzacji!\n"

#define MSGTR_MOVcomprhdr "MOV: Skompresowane nagwki nie s obsugiwane (na razie).\n"
#define MSGTR_MOVvariableFourCC "MOV: Uwaga! Wykryto zmienn FOURCC!?\n"
#define MSGTR_MOVtooManyTrk "MOV: Uwaga! Zbyt duo scieek!"
#define MSGTR_FoundAudioStream "==> Znaleziono strumie audio: %d\n"
#define MSGTR_FoundVideoStream "==> Znaleziono strumie video: %d\n"
#define MSGTR_DetectedTV "Wykryto TV! ;-)\n"
#define MSGTR_ErrorOpeningOGGDemuxer "Nie mona otworzy demuxera ogg.\n"
#define MSGTR_ASFSearchingForAudioStream "ASF: Szukanie strumieni audio (id:%d)\n"
#define MSGTR_CannotOpenAudioStream "Nie mona otworzy strumienia audio: %s\n"
#define MSGTR_CannotOpenSubtitlesStream "Nie mona otworzy strumienia z napisami: %s\n"
#define MSGTR_OpeningAudioDemuxerFailed "Nieudane otwarcie demuxera audio: %s\n"
#define MSGTR_OpeningSubtitlesDemuxerFailed "Nieudane otwarcie demuxera napisw: %s\n"
#define MSGTR_TVInputNotSeekable "Wejcia TV nie mona przeszukiwa! (Prawdopodobnie wyszukiwanie bedzie zmieniao kanay ;)\n"
#define MSGTR_DemuxerInfoAlreadyPresent "Demuxer info %s already present!\n"
#define MSGTR_ClipInfo "Informacja o klipie: \n"

#define MSGTR_LeaveTelecineMode "\ndemux_mpg: Wykryto progresywn sekwencj, wyczam 3:2 TELECINE\n"
#define MSGTR_EnterTelecineMode "\ndemux_mpg: Wykryto 3:2 TELECINE, wczam odwrotne telecine. Zmieniono FPS do %5.3f!  \n"


// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "Nie mog otworzy kodeka.\n"
#define MSGTR_CantCloseCodec "Nie mog zamkn kodeka.\n"

#define MSGTR_MissingDLLcodec "BD: Nie mog otworzy wymaganego kodeka DirectShow: %s.\n"
#define MSGTR_ACMiniterror "Nie mog zaadowa/zainicjalizowa kodeka Win32/ACM AUDIO (brakuje pliku DLL?)\n"
#define MSGTR_MissingLAVCcodec "Nie moge znale w libavcodec kodeka '%s'...\n"
#define MSGTR_MpegNoSequHdr "MPEG: BD: Koniec pliku podczas przeszukiwania nagwka sekwencji.\n"
#define MSGTR_CannotReadMpegSequHdr "BD: Nie mog odczyta nagwka sekwencji.\n"
#define MSGTR_CannotReadMpegSequHdrEx "BD: Nie mog odczyta rozszerzenia nagwka sekwencji.\n"
#define MSGTR_BadMpegSequHdr "MPEG: Nieprawidowy nagwek sekwencji.\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Nieprawidowe rozszerzenie nagwka sekwencji.\n"

#define MSGTR_ShMemAllocFail "Nie mog zaalokowa pamici dzielonej\n"
#define MSGTR_CantAllocAudioBuf "Nie mog zaalokowa bufora wyjciowego audio\n"

#define MSGTR_UnknownAudio "Nieznany/brakujcy format audio -> brak dwiku\n"

#define MSGTR_UsingExternalPP "[PP] Uywam zewntrznego filtra postprocessingu, max q = %d.\n"
#define MSGTR_UsingCodecPP "[PP] Uywam postprocessingu w kodeku, max q = %d.\n"
#define MSGTR_VideoAttributeNotSupportedByVO_VD "Atrybut video '%s' nie jest obsugiwany przez wybrane vo & vd.\n"
#define MSGTR_VideoCodecFamilyNotAvailableStr "Wybrana rodzina kodekw video [%s] (vfm=%d) niedostpna (wcz j podczas kompilacji)\n"
#define MSGTR_AudioCodecFamilyNotAvailableStr "Wybrana rodzina kodekw audio [%s] (afm=%d) niedostpna (wcz j podczas kompilacji)\n"
#define MSGTR_OpeningVideoDecoder "Otwieram dekoder video: [%s] %s\n"
#define MSGTR_OpeningAudioDecoder "Otwieram dekoder audio: [%s] %s\n"
#define MSGTR_UninitVideoStr "uninit video: %s\n"
#define MSGTR_UninitAudioStr "uninit audio: %s\n"
#define MSGTR_VDecoderInitFailed "Nieudana inicjalizacja VDecodera :(\n"
#define MSGTR_ADecoderInitFailed "Nieudana inicjalizacja ADecodera :(\n"
#define MSGTR_ADecoderPreinitFailed "Nieudana preinicjalizacja ADecodera :(\n"
#define MSGTR_AllocatingBytesForInputBuffer "dec_audio: Przydzielam %d bajtw dla bufora wejciowego\n"
#define MSGTR_AllocatingBytesForOutputBuffer "dec_audio: Przydzielam %d + %d = %d bajtw dla bufora wyjciowego\n"

// LIRC:
#define MSGTR_SettingUpLIRC "Wczam obsug LIRC...\n"
#define MSGTR_LIRCdisabled "Nie bdziesz mg uywa swojego pilota.\n"
#define MSGTR_LIRCopenfailed "Nieudane otwarcie obsugi LIRC.\n"
#define MSGTR_LIRCcfgerr "Nieudane odczytanie pliku konfiguracyjnego LIRC %s.\n"

// vf.c
#define MSGTR_CouldNotFindVideoFilter "Nie mog znale filtra video '%s'\n"
#define MSGTR_CouldNotOpenVideoFilter "Nie mog otworzy filtra video '%s'\n"
#define MSGTR_OpeningVideoFilter "Otwieram filtr video: "
#define MSGTR_CannotFindColorspace "Nie mog znale wsplnej przestrzeni koloru, nawet przez wstawienie 'scale' :(\n"

// vd.c
#define MSGTR_CodecDidNotSet "VDec: Kodek nie ustawia sh->disp_w i sh->disp_h, probuj to rozwiza.\n"
#define MSGTR_VoConfigRequest "VDec: danie konfiguracji vo - %d x %d (preferowana przestrze kolorw: %s)\n"
#define MSGTR_CouldNotFindColorspace "Nie mog znale pasujcej przestrzeni koloru - ponawiam prb z -vop scale...\n"
#define MSGTR_MovieAspectIsSet "Proporcje filmu to %.2f:1 - skaluj do prawidowych propocji.\n"
#define MSGTR_MovieAspectUndefined "Proporcje filmu nie s zdefiniowane - nie skaluj.\n"

// ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "O programie"
#define MSGTR_FileSelect "Wybr pliku ..."
#define MSGTR_SubtitleSelect "Wybr napisw ..."
#define MSGTR_OtherSelect "Wybr ..."
#define MSGTR_AudioFileSelect "Wybr zewntrznego kanau ..."
#define MSGTR_FontSelect "Wybr czcionki ..."
#define MSGTR_PlayList "Playlista"
#define MSGTR_Equalizer "Equalizer"
#define MSGTR_SkinBrowser "Przegldarka Skrek"
#define MSGTR_Network "Strumie sieciowy ..."
#define MSGTR_Preferences "Preferencje"
#define MSGTR_OSSPreferences "Konfiguracja sterownika OSS"
#define MSGTR_SDLPreferences "Konfiguracja sterownika SDL"
#define MSGTR_NoMediaOpened "Nie otwarto nonika."
#define MSGTR_VCDTrack "cieka VCD: %d"
#define MSGTR_NoChapter "Brak rozdziau"
#define MSGTR_Chapter "Rozdzia %d"
#define MSGTR_NoFileLoaded "Nie zaadowano pliku."

// --- buttons ---
#define MSGTR_Ok "OK"
#define MSGTR_Cancel "Anuluj"
#define MSGTR_Add "Dodaj"
#define MSGTR_Remove "Usu"
#define MSGTR_Clear "Wyczy"
#define MSGTR_Config "Konfiguracja"
#define MSGTR_ConfigDriver "Konfiguracja sterownika"
#define MSGTR_Browse "Przegldaj"

// --- error messages ---
#define MSGTR_NEMDB "Przykro mi, za mao pamici na bufor rysowania."
#define MSGTR_NEMFMR "Przykro mi, za mao pamici na renderowanie menu."
#define MSGTR_IDFGCVD "Przykro mi, nie znalazem kompatybilnego z GUI sterownika video."
#define MSGTR_NEEDLAVCFAME "Przykro mi, nie moesz odtwarza plikw innych ni MPEG za pomoc twojego urzdzenia DXR3/H+ bez przekodowania.\nProsz wcz lavc lub fame w konfiguracji DXR3/H+."

// --- skin loader error messages
#define MSGTR_SKIN_ERRORMESSAGE "[skin] bd w pliku konfiguracyjnym skrki w linii %d: %s"
#define MSGTR_SKIN_WARNING1 "[skin] ostrzeenie w pliku konfiguracyjnym skrki w linii %d: kontrolka znaleziona, ale poprzednia \"sekcja\" nie znaleziona ( %s )"
#define MSGTR_SKIN_WARNING2 "[skin] ostrzeenie w pliku konfiguracyjnym skrki w linii %d: kontrolka znaleziona, ale poprzednia \"podsekcja\" nie znaleziona (%s)"
#define MSGTR_SKIN_WARNING3 "[skin] ostrzeenie w pliku konfiguracyjnym skrki w linii %d: podsekcja nie jest obsugiwana przez t kontrolk (%s)"
#define MSGTR_SKIN_BITMAP_16bit "Bitmapy 16 bitowe lub mniejsze nie obsugiwane ( %s ).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound "plik nie znaleziony ( %s )\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "bd odczytu bmp ( %s )\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "bd odczytu tga ( %s )\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "bd odczytu png ( %s )\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "tga kompresowane RLE nie obsugiwane ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "nieznany typ pliku ( %s )\n"
#define MSGTR_SKIN_BITMAP_ConvertError "bd konwersji 24 bitw na 32 bity ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "nieznany komunikat: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "za mao pamici\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "za duo zadeklarowanych czcionek\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "nie znaleziono pliku z czcionk\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "nie znaleziono pliku z obrazem czcionki\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "nie istniejcy identyfikator czcionki ( %s )\n"
#define MSGTR_SKIN_UnknownParameter "nieznany parametr ( %s )\n"
#define MSGTR_SKINBROWSER_NotEnoughMemory "[skinbrowser] za mao pamici.\n"
#define MSGTR_SKIN_SKINCFG_SkinNotFound "Skrka nie znaleziona ( %s ).\n"
#define MSGTR_SKIN_SKINCFG_SkinCfgReadError "Bad odczytu pliku konfiguracyjnego skrki ( %s ).\n"
#define MSGTR_SKIN_LABEL "Skrki:"

// --- gtk menus
#define MSGTR_MENU_AboutMPlayer "O MPlayerze"
#define MSGTR_MENU_Open "Otwrz ..."
#define MSGTR_MENU_PlayFile "Odtwarzaj plik ..."
#define MSGTR_MENU_PlayVCD "Odtwarzaj VCD ..."
#define MSGTR_MENU_PlayDVD "Odtwarzaj DVD ..."
#define MSGTR_MENU_PlayURL "Odtwarzaj URL ..."
#define MSGTR_MENU_LoadSubtitle "Zaaduj napisy ..."
#define MSGTR_MENU_DropSubtitle "Wyaduj napisy ..."
#define MSGTR_MENU_LoadExternAudioFile "Zaaduj zewntrzny plik audio ..."
#define MSGTR_MENU_Playing "Odtwarzanie"
#define MSGTR_MENU_Play "Odtwarzaj"
#define MSGTR_MENU_Pause "Pauza"
#define MSGTR_MENU_Stop "Stop"
#define MSGTR_MENU_NextStream "Nastpny strumie"
#define MSGTR_MENU_PrevStream "Poprzedni strumie"
#define MSGTR_MENU_Size "Wielko"
#define MSGTR_MENU_NormalSize "Normalna wielko"
#define MSGTR_MENU_DoubleSize "Podwjna wielko"
#define MSGTR_MENU_FullScreen "Peen ekran"
#define MSGTR_MENU_DVD "DVD"
#define MSGTR_MENU_VCD "VCD"
#define MSGTR_MENU_PlayDisc "Odtwarzaj dysk ..."
#define MSGTR_MENU_ShowDVDMenu "Poka menu DVD"
#define MSGTR_MENU_Titles "Tytuy"
#define MSGTR_MENU_Title "Tytu %2d"
#define MSGTR_MENU_None "(puste)"
#define MSGTR_MENU_Chapters "Rozdziay"
#define MSGTR_MENU_Chapter "Rozdzia %2d"
#define MSGTR_MENU_AudioLanguages "Jzyki audio"
#define MSGTR_MENU_SubtitleLanguages "Jzyki napisw"
#define MSGTR_MENU_PlayList "Playlista"
#define MSGTR_MENU_SkinBrowser "Przegldarka skrek"
#define MSGTR_MENU_Preferences "Preferencje"
#define MSGTR_MENU_Exit "Wyjcie ..."
#define MSGTR_MENU_Mute "Mute"
#define MSGTR_MENU_Original "Oryginalne"
#define MSGTR_MENU_AspectRatio "Proporcje obrazu"
#define MSGTR_MENU_AudioTrack "cieka Audio"
#define MSGTR_MENU_Track "cieka %d"
#define MSGTR_MENU_VideoTrack "cieka Video"

// --- equalizer
#define MSGTR_EQU_Audio "Audio"
#define MSGTR_EQU_Video "Video"
#define MSGTR_EQU_Contrast "Kontrast: "
#define MSGTR_EQU_Brightness "Jasno: "
#define MSGTR_EQU_Hue "Hue: "
#define MSGTR_EQU_Saturation "Nasycenie: "
#define MSGTR_EQU_Front_Left "Lewy Przedni"
#define MSGTR_EQU_Front_Right "Prawy Przedni"
#define MSGTR_EQU_Back_Left "Lewy Tylny"
#define MSGTR_EQU_Back_Right "Prawy Tylny"
#define MSGTR_EQU_Center "Centralny"
#define MSGTR_EQU_Bass "Basowy"
#define MSGTR_EQU_All "Wszystkie"
#define MSGTR_EQU_Channel1 "Kana 1:"
#define MSGTR_EQU_Channel2 "Kana 2:"
#define MSGTR_EQU_Channel3 "Kana 3:"
#define MSGTR_EQU_Channel4 "Kana 4:"
#define MSGTR_EQU_Channel5 "Kana 5:"
#define MSGTR_EQU_Channel6 "Kana 6:"

// --- playlist
#define MSGTR_PLAYLIST_Path "cieka"
#define MSGTR_PLAYLIST_Selected "Wybrane pliki"
#define MSGTR_PLAYLIST_Files "Pliki"
#define MSGTR_PLAYLIST_DirectoryTree "Drzewo katalogw"

// --- preferences
#define MSGTR_PREFERENCES_Audio "Dwik"
#define MSGTR_PREFERENCES_Video "Video"
#define MSGTR_PREFERENCES_SubtitleOSD "Napisy i OSD"
#define MSGTR_PREFERENCES_Codecs "Kodeki i demuxery"
#define MSGTR_PREFERENCES_Misc "Rne"

#define MSGTR_PREFERENCES_None "Puste"
#define MSGTR_PREFERENCES_AvailableDrivers "Dostpne sterowniki:"
#define MSGTR_PREFERENCES_DoNotPlaySound "Nie odtwarzaj dwiku"
#define MSGTR_PREFERENCES_NormalizeSound "Normalizuj dwik"
#define MSGTR_PREFERENCES_EnEqualizer "Wcz equalizer"
#define MSGTR_PREFERENCES_ExtraStereo "Wcz extra stereo"
#define MSGTR_PREFERENCES_Coefficient "Wspczynnik:"
#define MSGTR_PREFERENCES_AudioDelay "Opnienie dwiku"
#define MSGTR_PREFERENCES_DoubleBuffer "Wcz podwjne buforowanie"
#define MSGTR_PREFERENCES_DirectRender "Wcz rysowanie bezporednie"
#define MSGTR_PREFERENCES_FrameDrop "Wcz zrzucanie ramek"
#define MSGTR_PREFERENCES_HFrameDrop "Wcz gwatowne zrzucanie ramek (niebezpieczne)"
#define MSGTR_PREFERENCES_Flip "Odwr obraz do gry nogami"
#define MSGTR_PREFERENCES_Panscan "Panscan: "
#define MSGTR_PREFERENCES_OSDTimer "Timer i wskaniki"
#define MSGTR_PREFERENCES_OSDProgress "Tylko belki"
#define MSGTR_PREFERENCES_OSDTimerPercentageTotalTime "Timer, czas procentowy i cakowity"
#define MSGTR_PREFERENCES_Subtitle "Napisy:"
#define MSGTR_PREFERENCES_SUB_Delay "Opnienie napisw: "
#define MSGTR_PREFERENCES_SUB_FPS "FPS:"
#define MSGTR_PREFERENCES_SUB_POS "Pozycja: "
#define MSGTR_PREFERENCES_SUB_AutoLoad "Wycz automatyczne adowanie napisw"
#define MSGTR_PREFERENCES_SUB_Unicode "Napisy w Unikodzie"
#define MSGTR_PREFERENCES_SUB_MPSUB "Konwertuj podane napisy do formatu napisw Mplayera"
#define MSGTR_PREFERENCES_SUB_SRT "Konwertuj podane napisy do formatu SRT (time based SubViewer)"
#define MSGTR_PREFERENCES_SUB_Overlap "Przecz nakadanie si napisw"
#define MSGTR_PREFERENCES_Font "Czcionka:"
#define MSGTR_PREFERENCES_FontFactor "Skala czcionki:"
#define MSGTR_PREFERENCES_PostProcess "Wcz postprocesing"
#define MSGTR_PREFERENCES_AutoQuality "Automatyczna jako: "
#define MSGTR_PREFERENCES_NI "Uyj parsera dla non-interleaved AVI"
#define MSGTR_PREFERENCES_IDX "Przebuduj tablice indeksw jesli to potrzebne"
#define MSGTR_PREFERENCES_VideoCodecFamily "Rodzina kodekw video:"
#define MSGTR_PREFERENCES_AudioCodecFamily "Rodzina kodekw audio:"
#define MSGTR_PREFERENCES_FRAME_OSD_Level "Poziom OSD"
#define MSGTR_PREFERENCES_FRAME_Subtitle "Napisy"
#define MSGTR_PREFERENCES_FRAME_Font "Czcionka"
#define MSGTR_PREFERENCES_FRAME_PostProcess "Postprocesing"
#define MSGTR_PREFERENCES_FRAME_CodecDemuxer "Kodek i demuxer"
#define MSGTR_PREFERENCES_FRAME_Cache "Pami podrczna"
#define MSGTR_PREFERENCES_FRAME_Misc "Rne"
#define MSGTR_PREFERENCES_OSS_Device "Urzdzenie:"
#define MSGTR_PREFERENCES_OSS_Mixer "Mikser:"
#define MSGTR_PREFERENCES_SDL_Driver "Sterownik:"
#define MSGTR_PREFERENCES_Message "Prosz pamita, e niektre funkcje wymagaja restartowania odtwarzania!"
#define MSGTR_PREFERENCES_DXR3_VENC "Enkoder video:"
#define MSGTR_PREFERENCES_DXR3_LAVC "Uyj LAVC (ffmpeg)"
#define MSGTR_PREFERENCES_DXR3_FAME "Uyj FAME"
#define MSGTR_PREFERENCES_FontEncoding1 "Unikod"
#define MSGTR_PREFERENCES_FontEncoding2 "Jzyki zachodnioeuropejskie (ISO-8859-1)"
#define MSGTR_PREFERENCES_FontEncoding3 "Jzyki zachodnioeuropejskiez Euro (ISO-8859-15)"
#define MSGTR_PREFERENCES_FontEncoding4 "Jzyki sowiaskie i rodkowoeuropejskie (ISO-8859-2)"
#define MSGTR_PREFERENCES_FontEncoding5 "Esperanto, Galician, maltaski, turecki (ISO-8859-3)"
#define MSGTR_PREFERENCES_FontEncoding6 "Stare znaki batyckie (ISO-8859-4)"
#define MSGTR_PREFERENCES_FontEncoding7 "Cyrylica (ISO-8859-5)"
#define MSGTR_PREFERENCES_FontEncoding8 "Arabski (ISO-8859-6)"
#define MSGTR_PREFERENCES_FontEncoding9 "Wspczesna greka (ISO-8859-7)"
#define MSGTR_PREFERENCES_FontEncoding10 "Turecki (ISO-8859-9)"
#define MSGTR_PREFERENCES_FontEncoding11 "Batycki (ISO-8859-13)"
#define MSGTR_PREFERENCES_FontEncoding12 "Celtycki (ISO-8859-14)"
#define MSGTR_PREFERENCES_FontEncoding13 "Znaki hebrajskie (ISO-8859-8)"
#define MSGTR_PREFERENCES_FontEncoding14 "Rosyjski (KOI8-R)"
#define MSGTR_PREFERENCES_FontEncoding15 "Ukraiski, biaoruski (KOI8-U/RU)"
#define MSGTR_PREFERENCES_FontEncoding16 "Uproszczone znaki chiskie (CP936)"
#define MSGTR_PREFERENCES_FontEncoding17 "Tradycyjne znaki chiskie (BIG5)"
#define MSGTR_PREFERENCES_FontEncoding18 "Znaki japoskie (SHIFT-JIS)"
#define MSGTR_PREFERENCES_FontEncoding19 "Znaki koreaskie (CP949)"
#define MSGTR_PREFERENCES_FontEncoding20 "Znaki tajskie (CP874)"
#define MSGTR_PREFERENCES_FontEncoding21 "Cyrylica Windows (CP1251)"
#define MSGTR_PREFERENCES_FontNoAutoScale "Bez autoskalowania"
#define MSGTR_PREFERENCES_FontPropWidth "Proporcjonalnie do szerokoci filmu"
#define MSGTR_PREFERENCES_FontPropHeight "Proporcjonalnie do wysokoci filmu"
#define MSGTR_PREFERENCES_FontPropDiagonal "Proporcjonalnie do przektnej filmu"
#define MSGTR_PREFERENCES_FontEncoding "Kodowanie:"
#define MSGTR_PREFERENCES_FontBlur "Rozmazanie:"
#define MSGTR_PREFERENCES_FontOutLine "Obramowanie:"
#define MSGTR_PREFERENCES_FontTextScale "Skalowanie tekstu:"
#define MSGTR_PREFERENCES_FontOSDScale "Skalowanie OSD:"
#define MSGTR_PREFERENCES_Cache "Pami podrczna"
#define MSGTR_PREFERENCES_CacheSize "Wielko pamici podrcznej: "
#define MSGTR_PREFERENCES_LoadFullscreen "Rozpocznij na penym ekranie"
#define MSGTR_PREFERENCES_SaveWinPos "Zapisz pooenie okna"
#define MSGTR_PREFERENCES_XSCREENSAVER "Zatrzymaj wygaszacz ekranu"
#define MSGTR_PREFERENCES_PlayBar "Wcz podrczny pasek"
#define MSGTR_PREFERENCES_AutoSync "Autosynchronizacja wcz/wycz"
#define MSGTR_PREFERENCES_AutoSyncValue "Autosynchronizacja: "
#define MSGTR_PREFERENCES_CDROMDevice "Urzdzenie CD-ROM:"
#define MSGTR_PREFERENCES_DVDDevice "Urzdzenie DVD:"
#define MSGTR_PREFERENCES_FPS "FPS:"
#define MSGTR_PREFERENCES_ShowVideoWindow "Poka okno video gdy nieaktywne"

#define MSGTR_ABOUT_UHU "Rozwijanie GUI sponsorowane przez UHU Linux\n"
#define MSGTR_ABOUT_CoreTeam "   Gwni czonkowie zespou MPlayera:\n"
#define MSGTR_ABOUT_AdditionalCoders "   Dodatkowki koderzy:\n"
#define MSGTR_ABOUT_MainTesters "   Gwni testerzy:\n"
				  
// --- messagebox
#define MSGTR_MSGBOX_LABEL_FatalError "Bd krytyczny!"
#define MSGTR_MSGBOX_LABEL_Error "Bd!"
#define MSGTR_MSGBOX_LABEL_Warning "Ostrzeenie!" 

#endif
